==> e2e-android-common-util-2.0.0-20190704.014429-121-sources.jar: com/dayouzc/e2e/core/util/LoadFileUtils.java <==
package com.dayouzc.e2e.core.util;

import android.annotation.SuppressLint;
import android.content.Context;
import android.text.format.Formatter;
import com.lzy.okgo.OkGo;
import com.lzy.okgo.callback.FileCallback;
import com.lzy.okgo.model.Progress;
import com.lzy.okgo.model.Response;
import com.lzy.okgo.request.base.Request;

import java.io.File;

import static org.chromium.base.ApplicationStatus.getApplicationContext;

/**
 * 下载文件并打开
 *
 * @author 何鑫
 * @date 2018/5/23 11:52
 */
@SuppressLint("SimpleDateFormat")
public class LoadFileUtils {
    public static final String DM_TARGET_FOLDER = "/mnt/sdcard/download/";
    public static Context sContext;

    private LoadFileUtils() {
    }

    public static void register(Context context) {
        sContext = context.getApplicationContext();
    }

    public static void downFile(String url) {
        // 从路径中获取
        String filename = null;
        if (filename == null || "".equals(filename)) {
            filename = url.substring(url.lastIndexOf("/") + 1);
        }
        checkFile(url, filename);
    }

    public static void checkFile(String url, String filename) {
        String filenames = DM_TARGET_FOLDER + filename;
        if (LoginUtils.fileIsExists(filenames)) {
            File file = new File(filenames);
            FileUtils.openFile(sContext, file);
        } else {
            fileDownLoad(url, filename);
        }
    }

    public static void fileDownLoad(String url, String filename) {
        OkGo.<File>get(url)
                .tag(sContext)
                .execute(new FileCallback(){
                    @Override
                    public void onStart(Request<File, ? extends Request> request) {
                        LogUtils.d("TAG", "正在下载中");
                        ToastUtils.showToast(sContext, "正在下载");
                    }

                    @Override
                    public void onSuccess(Response<File> response) {
                        File body = response.body();
                        FileUtils.openFile(sContext,body);
                    }

                    @Override
                    public void onError(Response<File> response) {
                        super.onError(response);
                        File body = response.body();
                        ToastUtils.showToast(sContext, "下载出错");
                    }

                    @Override
                    public void downloadProgress(Progress progress) {
                        String downloadLength = Formatter.formatFileSize(getApplicationContext(), progress.currentSize);
                        String totalLength = Formatter.formatFileSize(getApplicationContext(), progress.totalSize);
                        LogUtils.e("TAG", (Math.round(progress.fraction * 10000) * 1.0f / 100) + "%");
//                        ToastUtils.showShort((Math.round(progress.fraction * 10000) * 1.0f / 100) + "%");
                    }
                });

    }
}

==> e2e-android-common-util-2.0.0-20190806.120214-136-sources.jar: com/dayouzc/e2e/core/util/LoadFileUtils.java <==
package com.dayouzc.e2e.core.util;

import android.annotation.SuppressLint;
import android.content.Context;
import android.text.format.Formatter;
import com.lzy.okgo.OkGo;
import com.lzy.okgo.callback.FileCallback;
import com.lzy.okgo.model.Progress;
import com.lzy.okgo.model.Response;
import com.lzy.okgo.request.base.Request;

import java.io.File;

import static org.chromium.base.ContextUtils.getApplicationContext;

/**
 * 下载文件并打开
 *
 * @author 何鑫
 * @date 2018/5/23 11:52
 */
@SuppressLint("SimpleDateFormat")
public class LoadFileUtils {
    public static final String DM_TARGET_FOLDER = "/mnt/sdcard/download/";
    public static Context sContext;

    private LoadFileUtils() {
    }

    public static void register(Context context) {
        sContext = context.getApplicationContext();
    }

    public static void downFile(String url) {
        // 从路径中获取
        String filename = null;
        if (filename == null || "".equals(filename)) {
            filename = url.substring(url.lastIndexOf("/") + 1);
        }
        checkFile(url, filename);
    }

    public static void checkFile(String url, String filename) {
        String filenames = DM_TARGET_FOLDER + filename;
        if (LoginUtils.fileIsExists(filenames)) {
            File file = new File(filenames);
            FileUtils.openFile(sContext, file);
        } else {
            fileDownLoad(url, filename);
        }
    }

    public static void fileDownLoad(String url, String filename) {
        OkGo.<File>get(url)
                .tag(sContext)
                .execute(new FileCallback(){
                    @Override
                    public void onStart(Request<File, ? extends Request> request) {
                        LogUtils.d("TAG", "正在下载中");
                        ToastUtils.showToast(sContext, "正在下载");
                    }

                    @Override
                    public void onSuccess(Response<File> response) {
                        File body = response.body();
                        FileUtils.openFile(sContext,body);
                    }

                    @Override
                    public void onError(Response<File> response) {
                        super.onError(response);
                        File body = response.body();
                        ToastUtils.showToast(sContext, "下载出错");
                    }

                    @Override
                    public void downloadProgress(Progress progress) {
                        String downloadLength = Formatter.formatFileSize(getApplicationContext(), progress.currentSize);
                        String totalLength = Formatter.formatFileSize(getApplicationContext(), progress.totalSize);
                        LogUtils.e("TAG", (Math.round(progress.fraction * 10000) * 1.0f / 100) + "%");
//                        ToastUtils.showShort((Math.round(progress.fraction * 10000) * 1.0f / 100) + "%");
                    }
                });

    }
}
